@@ -1,4 +1,5 @@
 import re
+from .python3_compat import basestring
 
 class Comparator(object):
     def equals(self, other):
@@ -27,7 +28,7 @@ class IsA(Comparator):
         try:
             return isinstance(other, self._class)
         except TypeError:
-            return type(self._class) is type(other)
+            return self._class is type(other)
     def __repr__(self):
         return "<Is instance of %r >" % (self._class,)
 
@@ -64,12 +65,12 @@ class IsAlmost(Comparator):
             return False
 
 class Contains(Comparator):
-    def __init__(self, obj):
+    def __init__(self, *objs):
         super(Contains, self).__init__()
-        self._obj = obj
+        self._objs = objs
     def equals(self, other):
         try:
-            return self._obj in other
+            return all(obj in other for obj in self._objs)
         except TypeError:
             return False
 
@@ -112,7 +113,7 @@ class And(Comparator):
     def equals(self, other):
         return all(c.equals(other) for c in self.comparators)
 
-StrContains = lambda x: And(IsA(basestring), Contains(x))
+StrContains = lambda *xs: And(IsA(basestring), Contains(*xs))
 
 class Or(Comparator):
     def __init__(self, *comparators):
